@@ -3,12 +3,12 @@ set -e
 
 function print_info {
   printf "======================\n"
-  printf "Distribution:\t%s\n" "${DIST}"
-  printf "Dist name:\t%s\n" "${DISTNAME}"
-  printf "Build type:\t%s\n" "${BUILD}"
-  printf "Branch:\t\t%s\n" "${BRANCH}"
-  printf "Release:\t%s\n" "${RELEASE}"
-  printf "DMC Repository:\t%s\n" "${REPO_FILE}"
+  printf "%-16s%s\n" "Distribution:" "${DIST}"
+  printf "%-16s%s\n" "Dist name:" "${DISTNAME}"
+  printf "%-16s%s\n" "Build type:" "${BUILD}"
+  printf "%-16s%s\n" "Branch:" "${BRANCH}"
+  printf "%-16s%s\n" "Release:" "${RELEASE}"
+  printf "%-16s%s\n" "DMC Repository:" "${REPO_FILE}"
   printf "======================\n"
 }
 
@@ -32,13 +32,11 @@ DIST=$(rpm --eval "%{dist}" | cut -d. -f2)
 DISTNAME=${DIST}
 
 # Special handling of FC rawhide
-[[ "${DISTNAME}" == "fc35" ]] && DISTNAME="fc-rawhide"
 [[ "${DISTNAME}" == "fc36" ]] && DISTNAME="fc-rawhide"
+[[ "${DISTNAME}" == "fc37" ]] && DISTNAME="fc-rawhide"
 
 # Write repository files to /etc/yum.repos.d/ based on the branch name
-./ci/write-repo-file.sh
-
-REPO_FILE="${BUILD}/dmc-${BUILD}-${DISTNAME}.repo"
+REPO_FILE=$(./ci/write-repo-file.sh)
 print_info
 
 RPMBUILD=${PWD}/build
