@@ -66,6 +66,9 @@ public:
     friend int gfal_http_mkdirpG(plugin_handle plugin_data, const char *url, mode_t mode,
                                  gboolean rec_flag, GError **err);
 
+    friend int gfal_http_rename(plugin_handle plugin_data, const char* oldurl,
+                                const char* newurl, GError** err);;
+
     friend class TokenMapTest;
 
 private:
@@ -114,7 +117,7 @@ private:
 
     // Obtain Reva endpoint credentials
     void get_reva_credentials(Davix::RequestParams &params, const Davix::Uri &uri, const OP& operation);
-    
+
     // Obtain certificate credentials
     void get_certificate(Davix::RequestParams& params, const Davix::Uri& uri);
 
